/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id: version.h.in 418 2005-08-08 02:24:41Z aquamaniac $
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQDTAUS_VERSION_H
#define AQDTAUS_VERSION_H

#define AQDTAUS_VERSION_MAJOR 2
#define AQDTAUS_VERSION_MINOR 2
#define AQDTAUS_VERSION_PATCHLEVEL 3
#define AQDTAUS_VERSION_BUILD 0
#define AQDTAUS_VERSION_TAG "stable"
#define AQDTAUS_VERSION_FULL_STRING "2.2.3.0-stable"
#define AQDTAUS_VERSION_STRING "2.2.3"



#endif /* AQDTAUS_VERSION_H */


